@@ -54,8 +54,8 @@ static GObjectClass *parent_class;
 static void
 index_queue_entry_destroy (index_queue_entry *e)
 {
-	g_return_if_fail (e);
 	CORBA_Environment ev;
+	g_return_if_fail (e);
 	CORBA_exception_init (&ev);
 	CORBA_Object_release (e->cb, &ev);
 	CORBA_exception_free (&ev);
@@ -250,7 +250,7 @@ get_voice_list (void)
     
 		info = GNOME_Speech_VoiceInfo__alloc ();
 		eciGetVoiceName (tmp_handle, i, tmp);
-		info->language = 0;
+		info->language = CORBA_string_dup("en_US");
 		info->name = CORBA_string_dup (tmp);
 		gender = eciGetVoiceParam (tmp_handle, i, eciGender);
 		if (gender == 0)
@@ -300,7 +300,7 @@ voice_info_list_from_voice_list (GSList *l)
 			(GNOME_Speech_VoiceInfo *) l->data;
 		rv->_buffer[i].name = CORBA_string_dup (info->name);
 		rv->_buffer[i].gender = info->gender;
-		rv->_buffer[i].language = info->language;
+		rv->_buffer[i].language = CORBA_string_dup(info->language);
 		i++;
 		l = l->next;
 	}
